const path = require('path');
const fs = require('fs');
const handlerbars = require('handlebars');

const viewPath = path.join(process.cwd(), 'src', 'views');
const LAYOUT = path.join(viewPath, 'layout.html');

const read = (file) => {
  return new Promise((resolve, reject) => {
    fs.readFile(file, (err, data) => {
      if (err) {
        reject(err);
      }
      resolve(data.toString());
    });
  });
};

const readLayout = () => read(LAYOUT);
const readView = (viewName) => read(viewName);

module.exports = function (viewName, viewData) {
  const view = path.join(viewPath, `${viewName}.html`);
  return Promise.all([readLayout(), readView(view)])
    .then((data) => {
      const [l, v] = data;
      const viewTemp = handlerbars.compile(v);
      const vContext = { data: viewData.content };
      const vhtml = viewTemp(vContext);
      const layout = handlerbars.compile(l);
      const lContext = { title: viewData.title, body: vhtml };
      const lhtml = layout(lContext);
      this.writeHead(200, { 'Content-Type': 'text/html' });
      this.end(lhtml);
    })
    .catch((err) => {
      this.writeHead(500, { 'Content-Type': 'text/html' });
      this.end(`500 error: ${err}`);
    });
};
